// GOOD: https://dev.to/j3nnning/theme-setup-with-styled-components-functional-programming-4i5p
export const color = (key) => (props) => props.theme.colors[key];
export function checkColor(theme, color) {
    if (!color) {
        return false;
    }
    return color in theme.colors;
}
export function getAnyColor(theme, value) {
    if (!value) {
        return undefined;
    }
    return checkColor(theme, value) ? color(value)({ theme }) : value;
}
export const overflowedText = () => `
    text-overflow: ellipsis;
    white-space: nowrap;
    overflow: hidden;
`;
export const disabledCss = (extraCss = '') => `
    opacity: 0.6;
    pointer-events: none;
    ${extraCss}
`;
export const inputLabelCss = (props) => `
    color: ${color('grey')(props)};
    font-weight: 500;
    text-transform: uppercase;
    font-size: 13px;
    cursor: default;
`;
export const toPx = (value) => `${value}px`;
export const borderRadius = (props) => `${toPx(props.theme.borderRadius)}`;
export const border = (c) => (props) => `1px solid ${color(c)(props)}`;
export const padding = (size) => (props) => `${toPx(props.theme.paddings[size])}`;
export const selectPaddings = (props) => {
    const paddings = props.theme.paddings;
    return {
        small: toPx(paddings.small),
        medium: toPx(paddings.medium),
        large: toPx(paddings.large),
    };
};
export const getFontSize = (size) => {
    switch (size) {
        case 'small':
            return 14;
        case 'medium':
            return 16;
        case 'large':
            return 18;
        default:
            return 14;
    }
};
export const setSize = (props) => {
    const { size } = props;
    const paddings = selectPaddings(props);
    const fontSize = `
		font-size: ${toPx(getFontSize(size))};
	`;
    const small = `
		padding: ${paddings.small} ${paddings.medium};
	`;
    const medium = `
		padding: ${paddings.medium};
	`;
    const large = `
		padding: ${paddings.medium} ${paddings.large};
	`;
    switch (size) {
        case 'small':
            return small + fontSize;
        case 'medium':
            return medium + fontSize;
        case 'large':
            return large + fontSize;
        default:
            return medium + fontSize;
    }
};
export const isValidColors = (theme) => {
    const invalid = [];
    Object.entries(theme.colors).forEach(([name, color]) => {
        if (!CSS.supports('color', color)) {
            invalid.push(name);
            console.warn(`invalid color: ${name}: ${color} --> use six length format: #0f0f0f`);
        }
    });
    return invalid.length === 0;
};
export const clickEffect = {
    init: (props, options) => {
        var _a;
        return `
		&::after {
			content: '';
			display: block;
			position: absolute;
			border-radius: ${(_a = options === null || options === void 0 ? void 0 : options.borderRadius) !== null && _a !== void 0 ? _a : borderRadius(props)};
			left: 0;
			top: 0;
			width: 100%;
			height: 100%;
			box-shadow: 0 0 10px 5px ${color(props.color)(props)};
			opacity: 0;
			transition: 0.5s;
			pointer-events: none;
		}
	`;
    },
    active: () => `
		&::after {
			box-shadow: 0 0 0 0;
			opacity: 0.8;
			transition: 0s;
		}
	`,
};
export const cssIf = (value, condition = false) => (condition ? value : '');
